// Libraries
import { Component } from '@angular/core';
import { Store } from '@ngrx/store';
import { MatDialog } from '@angular/material';

// State management
import { GlobalState } from '@app/core/state';
import { AddAcademicYearRequest } from '@app/degree-planner/store/actions/addAcademicYear.actions';
import {
  ModifyPlanDialogComponent,
  DialogMode,
} from '@app/degree-planner/dialogs/modify-plan-dialog/modify-plan-dialog.component';
import { CreatePlan } from '@app/degree-planner/store/actions/plan.actions';

@Component({
  selector: 'cse-sidenav-menu-item',
  templateUrl: './sidenav-menu-item.component.html',
  styleUrls: ['./sidenav-menu-item.component.scss'],
})
export class SidenavMenuItemComponent {
  constructor(private store: Store<GlobalState>, public dialog: MatDialog) {}

  public addAcademicYear() {
    this.store.dispatch(new AddAcademicYearRequest());
  }

  public addDegreePlan() {
    const data: DialogMode = { mode: 'create' };
    this.dialog
      .open(ModifyPlanDialogComponent, { data })
      .afterClosed()
      .subscribe((result: { name: string } | undefined) => {
        if (result !== undefined && typeof result.name === 'string') {
          const name = result.name;
          const action = new CreatePlan({ name, primary: false });
          this.store.dispatch(action);
        }
      });
  }
}
